package com.main.controller;


import com.main.empService.EmployeeService;
import com.main.entity.Employee;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import reactor.core.publisher.Flux;
import reactor.core.publisher.Mono;

@RestController
@RequestMapping("/resource")
@Slf4j
public class ResourceController {

    @Autowired
    private EmployeeService service;

    @GetMapping("/getByDeptId/{id}")
    public Flux<Employee> fetchByDeptId(@PathVariable Integer id){
     Flux<Employee> flux=service.getByDeptId(id)
               .doOnNext(emp->log.info("Data fetch to resource controller successfully : {}", emp ))
             . doOnError(error-> log.error("Unable to fetch data from resource service ", error));
     return flux;
    }
    @PostMapping("/save")
    public Mono<Employee> save(@RequestBody Employee emp){
        Mono<Employee> mono=service.saveEmp(Mono.just(emp))
                .doOnNext(msg->log.info("Data send to controller successfully : {}", msg ))
                . doOnError(error-> log.error("Unable to send data from  service ", error));
        return mono;
    }


    @GetMapping("/getAll")
    public Flux<Employee> getAllEmp(){
        return service.getAll()
                .doOnNext(msg-> log.info("Data get from service succesfully:{}", msg))
                .doOnError(error-> log.error("unable to fetch data from DB", error));
    }





}
