package com.main.empService;


import com.main.entity.Employee;
import com.main.repository.EmployeeRepo;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import reactor.core.publisher.Flux;
import reactor.core.publisher.Mono;

@Service
@Slf4j
public class EmployeeService {


    @Autowired
    private EmployeeRepo repo;



    public Flux<Employee> getAll(){
        return repo.findAll()
                .doOnNext(msg-> log.info("Data fetch from DB Successfully: {}",msg))
                .doOnError(error-> log.error("unable to fetch Data from DB", error));
    }

    public Flux<Employee> getByDeptId(Integer id){
       Flux<Employee> flux= repo.findByDeptId(id)
                .doOnNext(emps->log.info("Data fetch from db successfully : {}",emps ))
               .doOnError(error-> log.error("no data found", error));

       return  flux;
    }

    public Mono<Employee> findById(int id){
        Mono<Employee> mono= repo.findById(id)
                .doOnNext(emp-> log.info("Data fetch from DB :, {} ",emp))
                        .doOnError(error->log.error("Data not found ", error));
                return mono;
    }

    public void deleteBYId(Employee emp){
        repo.delete(emp)
                .doOnNext(data-> log.info("Employee deleted from DB:,  {}",data))
                .doOnError(error-> log.error("Employee data not found in DB  :", error));
    }

    public Mono<Employee> saveEmp(Mono<Employee> mono){
        return mono.map(emp->repo.save(emp))
                .doOnNext(msg->log.info("data save in DB successfully: {}", msg))
                .doOnError(error-> log.error("unable to store data on DB", error))
                .thenReturn(mono.block());
    }


}
